@@ -1,6 +1,7 @@
 import __main__
 import os
 from django.contrib.sites.models import Site
+from django.db import transaction
 
 PROJECT_ROOT = os.path.abspath(os.path.dirname(__main__.__file__))
 LOG_DIR = os.path.join(PROJECT_ROOT ,'logs')
@@ -13,4 +14,6 @@ GENERATED_DIR = os.path.join(_config_dir ,'generated')
 try:
 	HOST = Site.objects.get_current().domain.split(':')[0]
 except:
+	transaction.rollback()
 	HOST = 'localhost'
+
